import {HttpException, HttpStatus, Injectable} from "@nestjs/common";
import {InjectRepository} from "@nestjs/typeorm";
import {Constants} from "src/utils/constants";
import {ResponseUtils} from "src/utils/response.utils";
import {EasyPaymentSectionCmsRepository} from "./easy-payment-section-cms.repository";
import {UpdateEasyPaymentSectionCmsDto} from "./dto/update-easy-payment-section-cms.dto";
import {EasyPaymentSectionCmsEntity} from "./entities/easy-payment-section-cms.entity";

@Injectable()
export class EasyPaymentSectionCmsService {
    constructor(
        @InjectRepository(EasyPaymentSectionCmsRepository)
        private readonly repository: EasyPaymentSectionCmsRepository
    ) {
    }

    async updateOrCreateData(
        dto: UpdateEasyPaymentSectionCmsDto
    ): Promise<EasyPaymentSectionCmsEntity | Error> {
        const isExists = await this.repository.find({isDeleted: false});
        if (Object.keys(isExists).length === 0) {
            const data = await this.repository.createEntity(dto);
            if (!data) {
                throw new HttpException(
                    Constants.NOT_FOUND,
                    HttpStatus.NOT_FOUND
                );
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            let id = isExists[0].id;
            const data = await this.repository.updateEntity(dto, id);
            if (!data) {
                throw new HttpException(
                    Constants.UPDATE_FAILED,
                    HttpStatus.BAD_REQUEST
                );
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<EasyPaymentSectionCmsEntity[] | Error> {
        const data = await this.repository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}