import {HttpException, HttpStatus, Injectable} from '@nestjs/common';
import {InjectRepository} from '@nestjs/typeorm';
import {Constants} from 'src/utils/constants';
import {ResponseUtils} from 'src/utils/response.utils';
import {PressAboutContentCmsRepository} from './press-about-content-cms.repository';
import {UpdatePressAboutContentCmsDto} from './dto/update-press-about-content-cms.dto';
import {PressAboutContentCmsEntity} from './entity/press-about-content-cms.entity';

@Injectable()
export class PressAboutContentCmsService {
    constructor(
        @InjectRepository(PressAboutContentCmsRepository)
        private readonly repository: PressAboutContentCmsRepository
    ) {
    }

    async updateOrCreateData(
        dto: UpdatePressAboutContentCmsDto
    ): Promise<PressAboutContentCmsEntity | Error> {
        const isExists = await this.repository.find({isDeleted: false});
        if (Object.keys(isExists).length === 0) {
            const data = await this.repository.createEntity(dto);
            if (!data) {
                throw new HttpException(
                    Constants.NOT_FOUND,
                    HttpStatus.NOT_FOUND
                );
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            let id = isExists[0].id;
            const data = await this.repository.updateEntity(id, dto);
            if (!data) {
                throw new HttpException(
                    Constants.UPDATE_FAILED,
                    HttpStatus.BAD_REQUEST
                );
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    // async create(dto: CreatePressAboutContentCmsDto): Promise<PressAboutContentCmsEntity | Error> {
    //     const data = await this.repository.createEntity(dto);
    //     if (!data) {
    //         throw new HttpException(
    //             Constants.CREATE_FAILED,
    //             HttpStatus.BAD_REQUEST
    //         );
    //     }
    //     return ResponseUtils.successResponseHandler(201, "Data Created Successfully", "data", data);
    // }

    async findAll(): Promise<PressAboutContentCmsEntity[] | Error> {
        const data = await this.repository.findByFilterQuery({});
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data Fetched Successfully", "data", data);
    }

    // async update(id: string, dto: UpdatePressAboutContentCmsDto): Promise<PressAboutContentCmsEntity | Error> {
    //     const data = await this.repository.updateEntity(id, dto);
    //     if (!data) {
    //         throw new HttpException(
    //             Constants.NOT_FOUND,
    //             HttpStatus.NOT_FOUND
    //         );
    //     }
    //     return ResponseUtils.successResponseHandler(200, "Data Updated Successfully", "data", data);
    // }

    // async findOne(id: string): Promise<PressAboutContentCmsEntity[] | Error> {
    //     const data = await this.repository.findByFilterQuery({ id: id });
    //     if (!data) {
    //         throw new HttpException(
    //             Constants.NOT_FOUND,
    //             HttpStatus.NOT_FOUND
    //         );
    //     }
    //     return ResponseUtils.successResponseHandler(200, "Data Fetched Successfully", "data", data);
    // }

    // async remove(id: string): Promise<boolean | Error> {
    //     const data = await this.repository.deleteEntity(id);
    //     if (!data) {
    //         throw new HttpException(
    //             Constants.NOT_FOUND,
    //             HttpStatus.NOT_FOUND
    //         );
    //     }
    //     return ResponseUtils.buildDeletedData(data, 200, "Data Deleted Successfully");
    // }
}
