import {
    Body,
    Controller,
    Get,
    HttpCode,
    HttpStatus,
    Post,
    UploadedFiles,
    UseGuards,
    UseInterceptors
} from '@nestjs/common';
import {SigninCmsService} from './signin-cms.service';
import {SigninCmsDto} from './dto/signin-cms.dto';
import {AdminAuthGuard} from "src/core/guards/admin-auth.guard";
import {Constants} from "src/utils/constants";
import {FileFieldsInterceptor} from "@nestjs/platform-express";
import {UploadedMulterFileI} from "../../SpacesModule/SpacesService";

@Controller({path: "signin-cms", version: Constants.API_VERSION_1})
export class SigninCmsController {
    constructor(private readonly service: SigninCmsService) {
    }

    @Post()
    @HttpCode(HttpStatus.OK)
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor([
        {name: 'googleButtonIcon', maxCount: 1},
        {name: 'facebookButtonIcon', maxCount: 1},
        {name: 'logo', maxCount: 1}
    ]))
    updateOrCreateData(
        @Body() dto: SigninCmsDto,
        @UploadedFiles() files: {
            googleButtonIcon?: UploadedMulterFileI,
            facebookButtonIcon?: UploadedMulterFileI,
            logo?: UploadedMulterFileI,
        }
    ) {
        return this.service.updateOrCreateData(dto, files);
    }

    @Get()
    findAll() {
        return this.service.findAll();
    }
}
