import {
    Body,
    Controller,
    Delete,
    Get,
    Param,
    Patch,
    Post,
    UploadedFiles,
    UseGuards,
    UseInterceptors
} from '@nestjs/common';
import {FileFieldsInterceptor} from '@nestjs/platform-express';
import {Constants} from 'src/utils/constants';
import {AdminAuthGuard} from 'src/core/guards/admin-auth.guard';
import {AccelerateContentService} from './accelerate-content.service';
import {CreateAccelerateContentDto} from './dto/create-accelerate-content.dto';
import {UpdateAccelerateContentDto} from './dto/update-accelerate-content.dto';
import {UploadedMulterFileI} from 'src/modules/SpacesModule/SpacesService';

@Controller({path: 'accelerate-content', version: Constants.API_VERSION_1})

export class AccelerateContentController {
    constructor(private readonly service: AccelerateContentService) {
    }

    @Post()
    // @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor([
        {name: 'image', maxCount: 1}
    ]))
    create(
        @Body() dto: CreateAccelerateContentDto,
        @UploadedFiles() files: {
            image?: UploadedMulterFileI,
        }
    ) {
        return this.service.create(dto, files);
    }

    @Get()
    @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }

    @Get(':id')
    @UseGuards(AdminAuthGuard)
    findOne(@Param('id') id: string) {
        return this.service.findOne(id);
    }

    @Patch('/:id')
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor([
        {name: 'image', maxCount: 1},
    ]))
    update(
        @Param('id') id: string,
        @Body() dto: UpdateAccelerateContentDto,
        @UploadedFiles() files: {
            image?: UploadedMulterFileI,
        }
    ) {
        return this.service.update(id, dto, files);
    }

    @Delete(':id')
    @UseGuards(AdminAuthGuard)
    async remove(@Param('id') id: string) {
        return await this.service.remove(id);
    }
}
