import {
    Body,
    Controller,
    Delete,
    Get,
    Param,
    Patch,
    Post,
    UploadedFiles,
    UseGuards,
    UseInterceptors
} from '@nestjs/common';
import {FileFieldsInterceptor} from '@nestjs/platform-express';
import {Constants} from 'src/utils/constants';
import {AdminAuthGuard} from 'src/core/guards/admin-auth.guard';
import {ApplicationsIntegrationService} from './applications-integration.service';
import {CreateApplicationsIntegrationDto} from './dto/create-applications-integration.dto';
import {UpdateApplicationsIntegrationDto} from './dto/update-applications-integration.dto';
import {UploadedMulterFileI} from 'src/modules/SpacesModule/SpacesService';

@Controller({path: 'applications-integration', version: Constants.API_VERSION_1})

export class ApplicationsIntegrationController {
    constructor(private readonly service: ApplicationsIntegrationService) {
    }

    @Post()
    // @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor([
        {name: 'logo', maxCount: 1}
    ]))
    create(
        @Body() dto: CreateApplicationsIntegrationDto,
        @UploadedFiles() files: {
            logo?: UploadedMulterFileI
        }
    ) {
        return this.service.create(dto, files);
    }

    @Get()
    @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }

    @Get(':id')
    @UseGuards(AdminAuthGuard)
    findOne(@Param('id') id: string) {
        return this.service.findOne(id);
    }

    @Patch('/:id')
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor([
        {name: 'logo', maxCount: 1}
    ]))
    update(
        @Param('id') id: string,
        @Body() dto: UpdateApplicationsIntegrationDto,
        @UploadedFiles() files: {
            logo?: UploadedMulterFileI
        }
    ) {
        return this.service.update(id, dto, files);
    }

    @Delete(':id')
    @UseGuards(AdminAuthGuard)
    async remove(@Param('id') id: string) {
        return await this.service.remove(id);
    }
}
