import {HttpException, HttpStatus, Injectable} from '@nestjs/common';
import {InjectRepository} from '@nestjs/typeorm';
import {Constants} from 'src/utils/constants';
import {ResponseUtils} from 'src/utils/response.utils';
import {BenefitsAndAdvantageSectionRepository} from './benefits-and-advantage-section.repository';
import {CreateBenefitsAndAdvantageSectionDto} from './dto/create-benefits-and-advantage-section.dto';
import {UpdateBenefitsAndAdvantageSectionDto} from './dto/update-benefits-and-advantage-section.dto';
import {BenefitsAndAdvantageSectionEntity} from './entity/benefits-and-advantage-section.entity';
import {DoSpacesService} from "../../SpacesModule/SpacesService/doSpacesService";
import {UploadedMulterFileI} from "../../SpacesModule/SpacesService";

@Injectable()
export class BenefitsAndAdvantageSectionService {
    constructor(
        @InjectRepository(BenefitsAndAdvantageSectionRepository)
        private readonly repository: BenefitsAndAdvantageSectionRepository,
        private readonly doSpacesService: DoSpacesService
    ) {
    }

    async create(dto: CreateBenefitsAndAdvantageSectionDto, files: {
        image?: UploadedMulterFileI,
    }): Promise<BenefitsAndAdvantageSectionEntity | Error> {
        if (files && files.image) {
            const url = await this.doSpacesService.uploadFile(files.image[0], "BenefitsAndAdvantageSection/");
            dto.image = url.toString();
        }
        const data = await this.repository.createEntity(dto);
        if (!data) {
            throw new HttpException(
                Constants.CREATE_FAILED,
                HttpStatus.BAD_REQUEST
            );
        }
        return ResponseUtils.successResponseHandler(201, "Data Created Successfully", "data", data);
    }

    async findAll(): Promise<BenefitsAndAdvantageSectionEntity[] | Error> {
        const data = await this.repository.findByFilterQuery({});
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data Fetched Successfully", "data", data);
    }

    async update(id: string, dto: UpdateBenefitsAndAdvantageSectionDto, files: {
        image?: UploadedMulterFileI,
    }): Promise<BenefitsAndAdvantageSectionEntity | Error> {
        if (files && files.image) {
            const url = await this.doSpacesService.uploadFile(files.image[0], "BenefitsAndAdvantageSection/");
            dto.image = url.toString();
        }
        const data = await this.repository.updateEntity(id, dto);
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data Updated Successfully", "data", data);
    }

    async findOne(id: string): Promise<BenefitsAndAdvantageSectionEntity[] | Error> {
        const data = await this.repository.findByFilterQuery({id: id});
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data Fetched Successfully", "data", data);
    }

    async remove(id: string): Promise<boolean | Error> {
        const data = await this.repository.deleteEntity(id);
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.buildDeletedData(data, 200, "Data Deleted Successfully");
    }
}
