import {Body, Controller, Delete, Get, Param, Patch, Post, UseGuards} from "@nestjs/common";
import {Constants} from "src/utils/constants";
import {AdminAuthGuard} from "src/core/guards/admin-auth.guard";
import {CareerTeamService} from "./career-team.service";
import {CreateCareerTeamDto} from "./dto/create-career-team.dto";
import {UpdateCareerTeamDto} from "./dto/update-career-team.dto";

@Controller({path: "career-team", version: Constants.API_VERSION_1})

export class CareerTeamController {
    constructor(private readonly service: CareerTeamService) {
    }

    @Post()
    @UseGuards(AdminAuthGuard)
    create(@Body() dto: CreateCareerTeamDto) {
        return this.service.create(dto);
    }

    @Get()
    @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }

    @Get(":id")
    @UseGuards(AdminAuthGuard)
    findOne(@Param("id") id: string) {
        return this.service.findOne(id);
    }

    @Patch("/:id")
    @UseGuards(AdminAuthGuard)
    update(
        @Param("id") id: string,
        @Body() dto: UpdateCareerTeamDto
    ) {
        return this.service.update(id, dto);
    }

    @Delete(":id")
    @UseGuards(AdminAuthGuard)
    async remove(@Param("id") id: string) {
        return await this.service.remove(id);
    }
}
