import {EntityRepository, getConnection, Repository} from "typeorm";
import {CreateCustomerReviewsDto} from "./dto/create-customer-reviews.dto";
import {UpdateCustomerReviewsDto} from "./dto/update-customer-reviews.dto";
import {CustomerReviewsEntity} from "./entity/customer-reviews.entity";

@EntityRepository(CustomerReviewsEntity)
export class CustomerReviewsRepository extends Repository<CustomerReviewsEntity> {

    async createEntity(dto: CreateCustomerReviewsDto): Promise<CustomerReviewsEntity | Error> {
        try {
            const {
                reviewMessage,
                userName,
                userPhoto,
                icon,
                iconText
            } = dto;
            const entity = this.create({
                reviewMessage,
                userName,
                userPhoto,
                icon,
                iconText
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<CustomerReviewsEntity[] | Error> {
        try {
            return await this.find({
                where: {...query, isDeleted: false}
            });
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<CustomerReviewsEntity | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateCustomerReviewsDto): Promise<CustomerReviewsEntity | Error> {
        try {
            await this.update(id, {
                reviewMessage: dto.reviewMessage,
                userName: dto.userName,
                userPhoto: dto.userPhoto,
                icon: dto.icon,
                iconText: dto.iconText
            });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(CustomerReviewsEntity)
                .set({isDeleted: true})
                .where("id = :id", {id: id})
                .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }
}