import {Body, Controller, Delete, Get, Param, Patch, Post, Req, UseGuards} from '@nestjs/common';
import {Constants} from 'src/utils/constants';
import {AuthGuard} from "../../core/guards/auth.guard";
import {CreateInviteDto} from './dto/createInvite.dto';
import {InvitesService} from './invites.service';
import {UpdateInviteDto} from './dto/updateInvite.dto';

@Controller({path: 'invites', version: Constants.API_VERSION_1})
export class InvitesController {
    constructor(private readonly service: InvitesService) {
    }

    @Post()
    @UseGuards(AuthGuard)
    create(@Body() dto: CreateInviteDto, @Req() request: any) {
        return this.service.create(dto, request.user);
    }

    @Get()
    @UseGuards(AuthGuard)
    findAll(@Req() request: any) {
        return this.service.findAll(request.user);
    }

    @Get('invite-details/:id')
    @UseGuards(AuthGuard)
    findInviteDetails(@Param('id') id: string) {
        return this.service.findInviteDetails(id);
    }

    @Get(':id')
    @UseGuards(AuthGuard)
    findOne(@Param('id') id: string, @Req() request: any) {
        return this.service.findOne(id, request.user);
    }

    @Patch(':id')
    @UseGuards(AuthGuard)
    update(@Param('id') id: string, @Body() dto: UpdateInviteDto, @Req() request: any) {
        return this.service.update(id, dto, request.user);
    }

    @Delete(':id')
    @UseGuards(AuthGuard)
    async remove(@Param('id') id: string, @Req() request: any) {
        return await this.service.remove(id, request.user);
    }
}
