import { MessageBody, SubscribeMessage, WebSocketGateway, WebSocketServer } from '@nestjs/websockets';
import { MessageService } from './message.service';
import { SingleMessageDto } from './dto/single-message.dto';
import { GroupMessageDto } from './dto/group-message.dto';
import { Server } from 'socket.io';
import { OneToOneMessageDto } from "./dto/one-to-one-message.dto";
import { AllGroupMessageDto } from "./dto/all-group-message.dto";
import { FileUploadDto } from "./dto/file-upload.dto";

@WebSocketGateway({ cors: { origin: '*' }, maxPayload: 1024 * 1024 * 100 })
export class MessageGateway {
    @WebSocketServer() server: Server;

    constructor(private readonly service: MessageService) { }

    @SubscribeMessage('createSingleMessage')
    async createSingleMessage(@MessageBody() dto: SingleMessageDto) {
        const message = await this.service.createSingleMessage(dto);
        this.server.emit(`singleMessage_${dto.receiverId}`, message);
        return message;
    }

    @SubscribeMessage('createGroupMessage')
    async createGroupMessage(@MessageBody() dto: GroupMessageDto) {
        const message = await this.service.createGroupMessage(dto);
        this.server.emit(`groupMessage_${dto.transactionId}`, message);
        return message;
    }

    @SubscribeMessage('findAllOneToOneMessage')
    findAllOneToOne(@MessageBody() dto: OneToOneMessageDto) {
        return this.service.findAllOneToOne(dto);
    }

    @SubscribeMessage('findAllGroupMessage')
    findAllGroupMessage(@MessageBody() dto: AllGroupMessageDto) {
        return this.service.findAllGroupMessage(dto);
    }

    @SubscribeMessage('file-upload')
    async handleFileUpload(@MessageBody() dto: FileUploadDto) {
        // Logic to handle file chunk
        return await this.service.handleFileChunk(dto);
    }

    afterInit(server: Server) {
        // console.log(server);
    }
}
