import { EntityRepository, In, MoreThanOrEqual, Not, Repository } from "typeorm";
import { SingleMessageDto } from "./dto/single-message.dto";
import { Message } from "./entities/message.entity";
import { OneToOneMessageDto } from "./dto/one-to-one-message.dto";
import { GroupMessageDto } from "./dto/group-message.dto";
import { AllGroupMessageDto } from "./dto/all-group-message.dto";
import { NotificationMessageDto } from "./dto/notification-message.dto";
import { User } from "../users/entities/user.entity";

@EntityRepository(Message)
export class MessageRepository extends Repository<Message> {
    async createEntity(dto: SingleMessageDto) {
        try {
            const entity = this.create({ ...dto });
            const message = await this.save(entity);

            const ids = [`'${dto.senderId}'`];
            const userMap = await this.findUserByIds(ids);

            if (userMap.has(dto.senderId)) {
                const userImage = userMap.get(dto.senderId);
                return {
                    ...message,
                    image: userImage
                }
            }

            return message;
        } catch (e) {
            return e;
        }
    }

    private async findUserByIds(ids: string[]) {
        try {
            const userMap = new Map<string, string>();
            if (ids.length == 0) return userMap;

            const usersQuery = `select id, image from users where id in (${ids.join(",")})`;
            const users: User[] = await this.query(usersQuery);
            for (const user of users) {
                userMap.set(user.id, user.image);
            }
            return userMap;

        } catch (error) {
            throw error;
        }
    }

    async findAllOneToOne(dto: OneToOneMessageDto): Promise<Message[] | Error> {
        const senderToReceive = { senderId: dto.senderId, receiverId: dto.receiverId };
        const receiverToSender = { receiverId: dto.senderId, senderId: dto.receiverId };
        try {
            const ids = [`'${dto.senderId}'`, `'${dto.receiverId}'`];
            const userMap = await this.findUserByIds(ids);
            const messages: Message[] = await this.find({ where: [senderToReceive, receiverToSender], order: { createdAt: 'ASC' } });

            return messages.map(x => {
                if (userMap.has(x.senderId)) {
                    const userImage = userMap.get(x.senderId);
                    return {
                        ...x,
                        image: userImage
                    }
                }

                return x;
            });
        } catch (error) {
            throw error;
        }
    }

    async createEntityForGroup(dto: GroupMessageDto) {
        try {
            const entity = this.create({ ...dto });
            const message = await this.save(entity);

            const ids = [`'${dto.senderId}'`];
            const userMap = await this.findUserByIds(ids);

            if (userMap.has(dto.senderId)) {
                const userImage = userMap.get(dto.senderId);
                return {
                    ...message,
                    image: userImage
                }
            }

            return message;
        } catch (e) {
            return e;
        }
    }

    async findAllGroupMessage(dto: AllGroupMessageDto): Promise<Message[] | Error> {
        try {
            const messages = await this.find({ where: { transactionId: dto.transactionId }, order: { createdAt: 'ASC' } });
            const setIds = new Set<string>();
            for (const message of messages) {
                if (!setIds.has(`'${message.senderId}'`)) {
                    setIds.add(`'${message.senderId}'`);
                }
            }
            const ids = [...setIds];
            const userMap = await this.findUserByIds(ids);
            return messages.map(x => {
                if (userMap.has(x.senderId)) {
                    const userImage = userMap.get(x.senderId);
                    return {
                        ...x,
                        image: userImage
                    }
                }

                return x;
            });
        } catch (error) {
            throw error;
        }
    }

    async findNotificationsMessageByUserId(dto: NotificationMessageDto) {
        try {
            const partyQuery = `SELECT transactionId FROM party where userId = '${dto.userId}'`;
            const parties = await this.manager.query(partyQuery);
            const transactionIds = parties.map((x: any) => `'${x.transactionId}'`);

            const message = await this.find({
                where: [
                    { createdAt: MoreThanOrEqual(new Date(dto.notificationTime)), receiverId: dto.userId },
                    { createdAt: MoreThanOrEqual(new Date(dto.notificationTime)), transactionId: In(transactionIds), senderId: Not(dto.userId) }
                ]
            });

            if (message.length == 0) return message;

            const userIds = [...new Set(message.map(x => `'${x.senderId}'`))];

            const userQuery = `select * from users where id in (${userIds.join(',')})`;
            const users = await this.query(userQuery);
            const userMap = new Map<string, any>();
            for (const user of users) {
                userMap.set(user.id, user);
            }

            return message.map(x => {
                const user = userMap.get(x.senderId);
                return {
                    ...x,
                    image: user.image
                }
            });
        } catch (error) {
            throw error;
        }
    }
}