import {Body, Controller, Delete, Get, Param, Patch, Post, Query, Req, UseGuards} from '@nestjs/common';
import {Constants} from 'src/utils/constants';
import {TransactionService} from './transaction.service';
import {CreateTransactionDto} from './dto/create-transaction.dto';
import {UpdateTransactionDto} from './dto/update-transaction.dto';
import {AuthGuard} from "../../core/guards/auth.guard";
import {PaginationDto} from './dto/create-pagination.dto';

@Controller({path: 'transaction', version: Constants.API_VERSION_1})
export class TransactionController {
    constructor(private readonly service: TransactionService) {
    }

    @Post()
    @UseGuards(AuthGuard)
    create(@Body() dto: CreateTransactionDto, @Req() request: any) {
        return this.service.create(dto, request.user);
    }

    @Get("/filter")
    @UseGuards(AuthGuard)
    filterTransaction(@Req() request: any,@Query() paginationDto: PaginationDto) {
        return this.service.filterTransaction(request.user, paginationDto);
    }

    @Get()
    @UseGuards(AuthGuard)
    findAll(@Req() request: any) {
        return this.service.findAll(request.user);
    }

    @Get('transaction-report')
    @UseGuards(AuthGuard)
    getTransactionReport(@Req() request: any) {
        return this.service.getTransactionReport(request.user);
    }

    @Get(':id')
    @UseGuards(AuthGuard)
    findOne(@Param('id') id: string) {
        return this.service.findOne(id);
    }

    @Patch(':id')
    @UseGuards(AuthGuard)
    update(@Param('id') id: string, @Body() dto: UpdateTransactionDto, @Req() request: any) {
        return this.service.update(id, dto, request.user);
    }

    @Delete(':id')
    @UseGuards(AuthGuard)
    async remove(@Param('id') id: string) {
        return await this.service.remove(id);
    }
}
